# new-checkit-bank

Update this README file with any information you'd like potential
adopters/contributors to this bank to know.

## About CheckIt

Learn more at <https://github.com/StevenClontz/checkit>.
